You are receiving this mail as a port that you maintain
is failing to build on the FreeBSD package build server.
Please investigate the failure and submit a PR to fix
build.

Maintainer:     [email protected]
Log URL:        
https://pkg-status.freebsd.org/beefy18/data/144i386-default/20261031_54c8a47fe587/logs/wasmtime-50.0.1.log
Build URL:      
https://pkg-status.freebsd.org/beefy18/build.html?mastername=144i386-default&build=20261031_54c8a47fe587
Log:

=>> Building www/wasmtime
build started at Sat Oct 31 21:49:58 UTC 2026
port directory: /usr/ports/www/wasmtime
package name: wasmtime-50.0.1
building for: FreeBSD 144i386-default-job-10 14.4-RELEASE-p12 FreeBSD 
14.4-RELEASE-p12 i386
maintained by: [email protected]
Makefile datestamp: -rw-r--r--  1 root wheel 11000 Oct 31 01:01 
/usr/ports/www/wasmtime/Makefile
Ports top last git commit: 54c8a47fe5879003b6b5d43e90ede9f0a769e9c2
Ports top unclean checkout: no
Port dir last git commit: 259861c6ef8b68db5d929752f4c942ad0cc2e7c7
Port dir unclean checkout: no
Poudriere version: poudriere-git-3.4.8-5-g3a769425
Host OSVERSION: 1600029
Jail OSVERSION: 1404000
Job Id: 10

---Begin Environment---
SHELL=/bin/sh
BLOCKSIZE=K
MAIL=/var/mail/root
MM_CHARSET=UTF-8
LANG=C.UTF-8
OSVERSION=1404000
STATUS=1
HOME=/root
PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin:/root/bin
MAKE_OBJDIR_CHECK_WRITABLE=0
UNAME_m=i386
UNAME_p=i386
UNAME_r=14.4-RELEASE-p12
LOCALBASE=/usr/local
UNAME_v=FreeBSD 14.4-RELEASE-p12
USER=root
POUDRIERE_NAME=poudriere-git
LIBEXECPREFIX=/usr/local/libexec/poudriere
POUDRIERE_VERSION=3.4.8-5-g3a769425
MASTERMNT=/usr/local/poudriere/data/.m/144i386-default/ref
LC_COLLATE=C
POUDRIERE_BUILD_TYPE=bulk
PACKAGE_BUILDING=yes
SAVED_TERM=
OUTPUT_REDIRECTED_STDERR=4
OUTPUT_REDIRECTED=1
PWD=/usr/local/poudriere/data/.m/144i386-default/10/.p
OUTPUT_REDIRECTED_STDOUT=3
P_PORTS_FEATURES=FLAVORS SUBPACKAGES SELECTED_OPTIONS
MASTERNAME=144i386-default
SCRIPTPREFIX=/usr/local/share/poudriere
SCRIPTNAME=bulk.sh
OLDPWD=/usr/local/poudriere/data/.m/144i386-default/ref/.p/pool
POUDRIERE_PKGNAME=poudriere-git-3.4.8-5-g3a769425
SCRIPTPATH=/usr/local/share/poudriere/bulk.sh
POUDRIEREPATH=/usr/local/bin/poudriere
---End Environment---

---Begin Poudriere Port Flags/Env---
PORT_FLAGS=
PKGENV=
FLAVOR=
MAKE_ARGS=
---End Poudriere Port Flags/Env---

---Begin OPTIONS List---
---End OPTIONS List---

--MAINTAINER--
[email protected]
--End MAINTAINER--

--CONFIGURE_ARGS--

--End CONFIGURE_ARGS--

--CONFIGURE_ENV--
PKG_CONFIG=pkgconf XDG_DATA_HOME=/wrkdirs/usr/ports/www/wasmtime/work  
XDG_CONFIG_HOME=/wrkdirs/usr/ports/www/wasmtime/work  
XDG_CACHE_HOME=/wrkdirs/usr/ports/www/wasmtime/work/.cache  
HOME=/wrkdirs/usr/ports/www/wasmtime/work 
TMPDIR="/wrkdirs/usr/ports/www/wasmtime/work" 
PATH=/wrkdirs/usr/ports/www/wasmtime/work/.bin:/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin:/root/bin
 
PKG_CONFIG_LIBDIR=/wrkdirs/usr/ports/www/wasmtime/work/.pkgconfig:/usr/local/libdata/pkgconfig:/usr/local/share/pkgconfig:/usr/libdata/pkgconfig
 SHELL=/bin/sh CONFIG_SHELL=/bin/sh
--End CONFIGURE_ENV--

--MAKE_ENV--
XDG_DATA_HOME=/wrkdirs/usr/ports/www/wasmtime/work  
XDG_CONFIG_HOME=/wrkdirs/usr/ports/www/wasmtime/work  
XDG_CACHE_HOME=/wrkdirs/usr/ports/www/wasmtime/work/.cache  
HOME=/wrkdirs/usr/ports/www/wasmtime/work 
TMPDIR="/wrkdirs/usr/ports/www/wasmtime/work" 
PATH=/wrkdirs/usr/ports/www/wasmtime/work/.bin:/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin:/root/bin
 
PKG_CONFIG_LIBDIR=/wrkdirs/usr/ports/www/wasmtime/work/.pkgconfig:/usr/local/libdata/pkgconfig:/usr/local/share/pkgconfig:/usr/libdata/pkgconfig
 MK_DEBUG_FILES=no MK_KERNEL_SYMBOLS=no SHELL=/bin/sh NO_LINT=YES 
PREFIX=/usr/local  LOCALBASE=/usr/local  CC="cc" CFLAGS="-O2 -pipe  
-fstack-protector-strong -fno-strict-aliasing "  CPP="cpp" CPPFLAGS=""  
LDFLAGS=" " LIBS=""  CXX="c++" CXXFLAGS="-O2 -pipe -fstack-protector-strong 
-fno-strict-aliasing  " BSD_INSTALL_PROGRAM="install  -s -m 555"  
BSD_INSTALL_LIB="install  -s -m 0644"  BSD_INSTALL_SCRIPT="install  -m 555"  
BSD_INSTALL_DATA="install  -m 0644"  BSD_INSTALL
_MAN="install  -m 444"
--End MAKE_ENV--

--PLIST_SUB--
OSREL=14.4 PREFIX=%D LOCALBASE=/usr/local  RESETPREFIX=/usr/local LIB32DIR=lib 
DOCSDIR="share/doc/wasmtime"  EXAMPLESDIR="share/examples/wasmtime"  
DATADIR="share/wasmtime"  WWWDIR="www/wasmtime"  ETCDIR="etc/wasmtime"
--End PLIST_SUB--

--SUB_LIST--
PREFIX=/usr/local LOCALBASE=/usr/local  DATADIR=/usr/local/share/wasmtime 
DOCSDIR=/usr/local/share/doc/wasmtime 
EXAMPLESDIR=/usr/local/share/examples/wasmtime  WWWDIR=/usr/local/www/wasmtime 
ETCDIR=/usr/local/etc/wasmtime
--End SUB_LIST--

---Begin make.conf---
USE_PACKAGE_DEPENDS=yes
BATCH=yes
WRKDIRPREFIX=/wrkdirs
PORTSDIR=/usr/ports
PACKAGES=/packages
DISTDIR=/distfiles
PACKAGE_BUILDING=yes
PACKAGE_BUILDING_FLAVORS=yes
MACHINE=i386
MACHINE_ARCH=i386
ARCH=${MACHINE_ARCH}
####  ####
# XXX: We really need this but cannot use it while 'make checksum' does not
# try the next mirror on checksum failure.  It currently retries the same
# failed mirror and then fails rather then trying another.  It *does*
# try the next if the size is mismatched though.
#MASTER_SITE_FREEBSD=yes
# Build ALLOW_MAKE_JOBS_PACKAGES with 3 jobs
MAKE_JOBS_NUMBER=3
#### Misc Poudriere ####
.include "/etc/make.conf.ports_env"
GID=0
UID=0
---End make.conf---
--Resource limits--
cpu time               (seconds, -t)  unlimited
file size           (512-blocks, -f)  unlimited
data seg size           (kbytes, -d)  524288
stack size              (kbytes, -s)  65536
core file size      (512-blocks, -c)  unlimited
max memory size         (kbytes, -m)  unlimited
locked memory           (kbytes, -l)  unlimited
max user processes              (-u)  89999
open files                      (-n)  8192
virtual mem size        (kbytes, -v)  unlimited
swap limit              (kbytes, -w)  unlimited
socket buffer size       (bytes, -b)  unlimited
pseudo-terminals                (-p)  unlimited
kqueues                         (-k)  unlimited
umtx shared locks               (-o)  unlimited
pipebuf                         (-y)  unlimited
--End resource limits--
=======================<phase: check-sanity   >============================
===== env: NO_DEPENDS=yes USER=root UID=0 GID=0
===>  License APACHE20 accepted by the user
===========================================================================
=======================<phase: pkg-depends    >============================
===== env: USE_PACKAGE_DEPENDS_ONLY=1 USER=root UID=0 GID=0
===>   wasmtime-50.0.1 depends on file: /usr/local/sbin/pkg - not found
===>   Installing existing package /packages/All/pkg-2.8.4.pkg
[144i386-default-job-10] Installing pkg-2.8.4...
[144i386-default-job-10] Extracting pkg-2.8.4: .......... done
===>   wasmtime-50.0.1 depends on file: /usr/local/sbin/pkg - found
===>   Returning to build of wasmtime-50.0.1
===========================================================================
=======================<phase: fetch-depends  >============================
===== env: USE_PACKAGE_DEPENDS_ONLY=1 USER=root UID=0 GID=0
===========================================================================
=======================<phase: fetch          >============================
===== env: NO_DEPENDS=yes USER=root UID=0 GID=0
===>  License APACHE20 accepted by the user
=> rust/crates/gimli-0.34.0.crate doesn't seem to exist in /portdistfiles.
=> Attempting to fetch https://static.crates.io/crates/gimli/gimli-0.34.0.crate
rust/crates/gimli-0.34.0.crate                         327 kB   24 MBps    00s
=> rust/crates/json-from-wast-0.261.0.crate doesn't seem to exist in 
/portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/json-from-wast/json-from-wast-0.261.0.crate
rust/crates/json-from-wast-0.261.0.crate                14 kB   44 MBps    00s
=> rust/crates/macro-string-0.3.0.crate doesn't seem to exist in /portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/macro-string/macro-string-0.3.0.crate
rust/crates/macro-string-0.3.0.crate                    13 kB   68 MBps    00s
=> rust/crates/wasm-compose-0.261.0.crate doesn't seem to exist in 
/portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/wasm-compose/wasm-compose-0.261.0.crate
rust/crates/wasm-compose-0.261.0.crate                  56 kB   10 MBps    00s
=> rust/crates/wasm-encoder-0.259.0.crate doesn't seem to exist in 
/portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/wasm-encoder/wasm-encoder-0.259.0.crate
rust/crates/wasm-encoder-0.259.0.crate                  88 kB   11 MBps    00s
=> rust/crates/wasm-metadata-0.259.0.crate doesn't seem to exist in 
/portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/wasm-metadata/wasm-metadata-0.259.0.crate
rust/crates/wasm-metadata-0.259.0.crate                 26 kB   19 MBps    00s
=> rust/crates/wasm-metadata-0.261.0.crate doesn't seem to exist in 
/portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/wasm-metadata/wasm-metadata-0.261.0.crate
rust/crates/wasm-metadata-0.261.0.crate                 25 kB   48 MBps    00s
=> rust/crates/wasm-mutate-0.261.0.crate doesn't seem to exist in 
/portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/wasm-mutate/wasm-mutate-0.261.0.crate
rust/crates/wasm-mutate-0.261.0.crate                   96 kB   17 MBps    00s
=> rust/crates/wasm-smith-0.261.0.crate doesn't seem to exist in /portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/wasm-smith/wasm-smith-0.261.0.crate
rust/crates/wasm-smith-0.261.0.crate                   111 kB   16 MBps    00s
=> rust/crates/wasm-wave-0.261.0.crate doesn't seem to exist in /portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/wasm-wave/wasm-wave-0.261.0.crate
rust/crates/wasm-wave-0.261.0.crate                     50 kB   17 MBps    00s
=> rust/crates/wasmparser-0.259.0.crate doesn't seem to exist in /portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/wasmparser/wasmparser-0.259.0.crate
rust/crates/wasmparser-0.259.0.crate                   275 kB   32 MBps    00s
=> rust/crates/wasmprinter-0.261.0.crate doesn't seem to exist in 
/portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/wasmprinter/wasmprinter-0.261.0.crate
rust/crates/wasmprinter-0.261.0.crate                   48 kB   18 MBps    00s
=> rust/crates/wit-bindgen-0.62.0.crate doesn't seem to exist in /portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/wit-bindgen/wit-bindgen-0.62.0.crate
rust/crates/wit-bindgen-0.62.0.crate                    73 kB   18 MBps    00s
=> rust/crates/wit-bindgen-core-0.62.0.crate doesn't seem to exist in 
/portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/wit-bindgen-core/wit-bindgen-core-0.62.0.crate
rust/crates/wit-bindgen-core-0.62.0.crate               38 kB   12 MBps    00s
=> rust/crates/wit-bindgen-rust-0.62.0.crate doesn't seem to exist in 
/portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/wit-bindgen-rust/wit-bindgen-rust-0.62.0.crate
rust/crates/wit-bindgen-rust-0.62.0.crate               62 kB   18 MBps    00s
=> rust/crates/wit-bindgen-rust-macro-0.62.0.crate doesn't seem to exist in 
/portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/wit-bindgen-rust-macro/wit-bindgen-rust-macro-0.62.0.crate
rust/crates/wit-bindgen-rust-macro-0.62.0.crate          14 kB   42 MBps    00s
<snip>
    |                               ^^^^^^^^^^
    |
   ::: 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/sharded-slab-0.1.4/src/lib.rs:961:17
    |
961 |                 test_println!("-> shard={:?} does not exist! THIS IS A 
BUG", shard_idx);
    |                 
----------------------------------------------------------------------- in this 
macro invocation
    |
    = help: consider using a Cargo feature instead
    = help: or consider adding in `Cargo.toml` the `check-cfg` lint config for 
the lint:
             [lints.rust]
             unexpected_cfgs = { level = "warn", check-cfg = 
['cfg(slab_print)'] }
    = help: or consider adding 
`println!("cargo::rustc-check-cfg=cfg(slab_print)");` to the top of the 
`build.rs`
    = note: see 
<https://doc.rust-lang.org/nightly/rustc/check-cfg/cargo-specifics.html> for 
more information about checking conditional configuration
    = note: this warning originates in the macro `test_println` (in Nightly 
builds, run with -Z macro-backtrace for more info)

warning: use of deprecated constant `std::usize::MAX`: replaced by the `MAX` 
associated constant on this type
  --> 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/sharded-slab-0.1.4/src/tid.rs:90:29
   |
90 |             id: std::usize::MAX,
   |                             ^^^
   |
   = note: `#[warn(deprecated)]` on by default

warning: use of deprecated constant `std::usize::MAX`: replaced by the `MAX` 
associated constant on this type
  --> 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/sharded-slab-0.1.4/src/tid.rs:98:32
   |
98 |         self.id == std::usize::MAX
   |                                ^^^

warning: `sharded-slab` (lib) generated 106 warnings
   Compiling tokio-rustls v0.26.4
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=tokio_rustls 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/tokio-rustls-0.26.4
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/tokio-rustls-0.26.4/Cargo.toml
 CARGO_PKG_AUTHORS='' CARGO_PKG_DESCRIPTION='Asynchronous TLS/SSL streams for 
Tokio using Rustls.' 
CARGO_PKG_HOMEPAGE='https://github.com/rustls/tokio-rustls' 
CARGO_PKG_LICENSE='MIT OR Apache-2.0' CARGO_PKG_LICENSE_FILE='' 
CARGO_PKG_NAME=tokio-rustls CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/rustls/tokio-rustls' 
CARGO_PKG_RUST_VERSION=1.71 CARGO_PKG_VERSION=0.26.4 CARGO_PKG_VERSION_MAJOR=0 
CARGO_PKG_VERSION_MINOR=26 CARGO_PKG_VERSION_PATCH=4 CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps 
/usr/local/bin/rustc --crate-name tokio_rustls --edition=2021 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates
/tokio-rustls-0.26.4/src/lib.rs --error-format=json 
--json=diagnostic-rendered-ansi,artifacts,future-incompat --crate-type lib 
--emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --cfg 'feature="logging"' --cfg 
'feature="ring"' --cfg 'feature="tls12"' --check-cfg 'cfg(docsrs,test)' 
--check-cfg 'cfg(feature, values("aws-lc-rs", "aws_lc_rs", "brotli", "default", 
"early-data", "fips", "logging", "ring", "tls12", "zlib"))' -C 
metadata=77c63299b74a4ed4 -C extra-filename=-44315e37174c68fe --out-dir 
/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps --extern 
rustls=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/librustls-134bd2bef2440bac.rmeta
 --extern 
tokio=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libtokio-de22396ecb88af47.rmeta
 --cap-lints warn -C linker=cc -L 
native=/wrkdirs/usr/ports/www/wasmtime/work/target/rele
ase/build/ring-fff0598a907d0028/out`
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=httparse 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/httparse-1.10.1
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/httparse-1.10.1/Cargo.toml
 CARGO_PKG_AUTHORS='Sean McArthur <[email protected]>' 
CARGO_PKG_DESCRIPTION='A tiny, safe, speedy, zero-copy HTTP/1.x parser.' 
CARGO_PKG_HOMEPAGE='' CARGO_PKG_LICENSE='MIT OR Apache-2.0' 
CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NAME=httparse CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/seanmonstar/httparse' 
CARGO_PKG_RUST_VERSION='' CARGO_PKG_VERSION=1.10.1 CARGO_PKG_VERSION_MAJOR=1 
CARGO_PKG_VERSION_MINOR=10 CARGO_PKG_VERSION_PATCH=1 CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps 
OUT_DIR=/wrkdirs/usr/ports/www/wasmtime/work/target/release/build/httparse-a4e7179aaeeebba1/out
 /usr/local/bin/rustc --crate-name httparse --edition=2
018 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/httparse-1.10.1/src/lib.rs
 --error-format=json --json=diagnostic-rendered-ansi,artifacts,future-incompat 
--crate-type lib --emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --warn=unexpected_cfgs --check-cfg 
'cfg(httparse_simd)' --check-cfg 'cfg(httparse_simd_target_feature_avx2)' 
--check-cfg 'cfg(httparse_simd_target_feature_sse42)' --check-cfg 
'cfg(httparse_simd_neon_intrinsics)' --cfg 'feature="default"' --cfg 
'feature="std"' --check-cfg 'cfg(docsrs,test)' --check-cfg 'cfg(feature, 
values("default", "std"))' -C metadata=97db09a587b1bd6e -C 
extra-filename=-eda0affd5a496ace --out-dir 
/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps --cap-lints 
warn -C linker=cc --cfg httparse_simd_neon_intrinsics --cfg httparse_simd`
   Compiling wasmtime-wasi-nn v50.0.1 
(/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/crates/wasi-nn)
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=build_script_build 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/crates/wasi-nn
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/crates/wasi-nn/Cargo.toml
 CARGO_PKG_AUTHORS='The Wasmtime Project Developers' 
CARGO_PKG_DESCRIPTION='Wasmtime implementation of the wasi-nn API' 
CARGO_PKG_HOMEPAGE='' CARGO_PKG_LICENSE='Apache-2.0 WITH LLVM-exception' 
CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NAME=wasmtime-wasi-nn 
CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/bytecodealliance/wasmtime' 
CARGO_PKG_RUST_VERSION=1.97.0 CARGO_PKG_VERSION=50.0.1 
CARGO_PKG_VERSION_MAJOR=50 CARGO_PKG_VERSION_MINOR=0 CARGO_PKG_VERSION_PATCH=1 
CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps 
/usr/local/bin/rustc --crate-name build_script_build --edition=2024 
crates/wasi-nn/build.rs --error-format=json 
--json=diagnostic-rendered-ansi,artif
acts,future-incompat --crate-type bin --emit=dep-info,link -C embed-bitcode=no 
'--allow=clippy::all' '--warn=clippy::useless_conversion' 
--warn=unused_macro_rules --warn=unused_lifetimes --warn=unused_import_braces 
--warn=unused_extern_crates --warn=unstable_features 
'--warn=clippy::unnecessary_to_owned' '--warn=clippy::unnecessary_mut_passed' 
'--warn=clippy::unnecessary_fallible_conversions' 
'--warn=clippy::unnecessary_cast' '--warn=clippy::uninlined_format_args' 
--warn=unexpected_cfgs --warn=trivial_numeric_casts 
'--warn=clippy::redundant_field_names' 
'--warn=clippy::multiple_bound_locations' '--warn=clippy::map_clone' 
'--warn=clippy::manual_strip' '--warn=clippy::from_over_into' 
'--warn=clippy::extra_unused_type_parameters' '--warn=clippy::clone_on_copy' 
'--warn=clippy::allow_attributes_without_reason' --check-cfg 
'cfg(pulley_tail_calls)' --check-cfg 'cfg(pulley_assume_llvm_makes_tail_calls)' 
--check-cfg 'cfg(pulley_disable_interp_simd)' --check-cfg 'cfg(arc_try_new)' --c
heck-cfg 'cfg(fuzzing)' --check-cfg 'cfg(gc_zeal)' -C debug-assertions=off 
--cfg 'feature="default"' --cfg 'feature="openvino"' --cfg 'feature="winml"' 
--check-cfg 'cfg(docsrs,test)' --check-cfg 'cfg(feature, values("default", 
"onnx", "onnx-cuda", "onnx-download", "openvino", "ort-tracing", "pytorch", 
"winml"))' -C metadata=f29f3f4b5b085fe2 -C extra-filename=-14c7b654b7bfc07f 
--out-dir 
/wrkdirs/usr/ports/www/wasmtime/work/target/release/build/wasmtime-wasi-nn-14c7b654b7bfc07f
 -C strip=debuginfo -L 
dependency=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps --extern 
walkdir=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libwalkdir-76ba27bc89a130ae.rlib
 -C linker=cc`
   Compiling matchers v0.2.0
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=matchers 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/matchers-0.2.0
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/matchers-0.2.0/Cargo.toml
 CARGO_PKG_AUTHORS='Eliza Weisman <[email protected]>' 
CARGO_PKG_DESCRIPTION='Regex matching on character and byte streams.
' CARGO_PKG_HOMEPAGE='https://github.com/hawkw/matchers' CARGO_PKG_LICENSE=MIT 
CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NAME=matchers CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/hawkw/matchers' 
CARGO_PKG_RUST_VERSION='' CARGO_PKG_VERSION=0.2.0 CARGO_PKG_VERSION_MAJOR=0 
CARGO_PKG_VERSION_MINOR=2 CARGO_PKG_VERSION_PATCH=0 CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps 
/usr/local/bin/rustc --crate-name matchers --edition=2018 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/matchers-0.2.0/src/lib.rs
 --error-format=json --json=diagnostic-rendered-ansi,artifacts,future-incompat 
--crate-type lib --emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --check-cfg 'cfg(docsrs,test)' --check-cfg 
'cfg(feature, values("unicode"))' -C metadata=2e3cdd2c9c341bee -C 
extra-filename=-12903dc96595f18d --out-dir 
/wrkdirs/usr/ports/www/wasmtime/work/target/release/d
eps -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps --extern 
regex_automata=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libregex_automata-307e72850065b13a.rmeta
 --cap-lints warn -C linker=cc`
   Compiling webpki-roots v1.0.7
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=webpki_roots 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/webpki-roots-1.0.7
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/webpki-roots-1.0.7/Cargo.toml
 CARGO_PKG_AUTHORS='' CARGO_PKG_DESCRIPTION='Mozilla'\''s CA root certificates 
for use with webpki' 
CARGO_PKG_HOMEPAGE='https://github.com/rustls/webpki-roots' 
CARGO_PKG_LICENSE=CDLA-Permissive-2.0 CARGO_PKG_LICENSE_FILE='' 
CARGO_PKG_NAME=webpki-roots CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/rustls/webpki-roots' 
CARGO_PKG_RUST_VERSION=1.64 CARGO_PKG_VERSION=1.0.7 CARGO_PKG_VERSION_MAJOR=1 
CARGO_PKG_VERSION_MINOR=0 CARGO_PKG_VERSION_PATCH=7 CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps 
/usr/local/bin/rustc --crate-name webpki_roots --edition=2021 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/we
bpki-roots-1.0.7/src/lib.rs --error-format=json 
--json=diagnostic-rendered-ansi,artifacts,future-incompat --crate-type lib 
--emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --check-cfg 'cfg(docsrs,test)' --check-cfg 
'cfg(feature, values())' -C metadata=38e1e0d2013a0292 -C 
extra-filename=-7f36fe45a8883900 --out-dir 
/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps --extern 
pki_types=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/librustls_pki_types-2636aba1ea5dba13.rmeta
 --cap-lints warn -C linker=cc`
   Compiling tracing-log v0.2.0
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=tracing_log 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/tracing-log-0.2.0
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/tracing-log-0.2.0/Cargo.toml
 CARGO_PKG_AUTHORS='Tokio Contributors <[email protected]>' 
CARGO_PKG_DESCRIPTION='Provides compatibility between `tracing` and the `log` 
crate.
' CARGO_PKG_HOMEPAGE='https://tokio.rs' CARGO_PKG_LICENSE=MIT 
CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NAME=tracing-log CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/tokio-rs/tracing' 
CARGO_PKG_RUST_VERSION=1.56.0 CARGO_PKG_VERSION=0.2.0 CARGO_PKG_VERSION_MAJOR=0 
CARGO_PKG_VERSION_MINOR=2 CARGO_PKG_VERSION_PATCH=0 CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps 
/usr/local/bin/rustc --crate-name tracing_log --edition=2018 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/tracing-log-0.2.0/src/lib.rs
 --error-format=json --json=diagnostic-rendered-ansi,artifacts,future-incompat 
--crate-type lib --emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --cfg 'feature="log-tracer"' --cfg 
'feature="std"' --check-cfg 'cfg(docsrs,test)' --check-cfg 'cfg(feature, 
values("ahash", "default", "interest-cache", "log-tracer", "lru", "std"))' -C 
metadata=603890e06050
4cdf -C extra-filename=-f4210e0ba5c1c675 --out-dir 
/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps --extern 
log=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/liblog-577b4e335898a030.rmeta
 --extern 
once_cell=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libonce_cell-5d9acb04abc1e02f.rmeta
 --extern 
tracing_core=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libtracing_core-78bd3a1088ebf972.rmeta
 --cap-lints warn -C linker=cc`
warning: lint `no_mangle_generic_items` has been removed: converted into hard 
error, generic items must always be mangled
   --> 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/tracing-log-0.2.0/src/lib.rs:111:5
    |
111 |     no_mangle_generic_items,
    |     ^^^^^^^^^^^^^^^^^^^^^^^
    |
    = note: `#[warn(renamed_and_removed_lints)]` on by default

warning: lint `private_in_public` has been removed: replaced with another group 
of lints, see RFC <https://rust-lang.github.io/rfcs/2145-type-privacy.html> for 
more information
   --> 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/tracing-log-0.2.0/src/lib.rs:115:5
    |
115 |     private_in_public,
    |     ^^^^^^^^^^^^^^^^^

warning: `tracing-log` (lib) generated 2 warnings
   Compiling thread_local v1.1.4
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=thread_local 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/thread_local-1.1.4
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/thread_local-1.1.4/Cargo.toml
 CARGO_PKG_AUTHORS='Amanieu d'\''Antras <[email protected]>' 
CARGO_PKG_DESCRIPTION='Per-object thread-local storage' CARGO_PKG_HOMEPAGE='' 
CARGO_PKG_LICENSE=Apache-2.0/MIT CARGO_PKG_LICENSE_FILE='' 
CARGO_PKG_NAME=thread_local CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/Amanieu/thread_local-rs' 
CARGO_PKG_RUST_VERSION='' CARGO_PKG_VERSION=1.1.4 CARGO_PKG_VERSION_MAJOR=1 
CARGO_PKG_VERSION_MINOR=1 CARGO_PKG_VERSION_PATCH=4 CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps 
/usr/local/bin/rustc --crate-name thread_local --edition=2018 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/thread_local-1.1.4/src/lib
.rs --error-format=json 
--json=diagnostic-rendered-ansi,artifacts,future-incompat --crate-type lib 
--emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --check-cfg 'cfg(docsrs,test)' --check-cfg 
'cfg(feature, values("criterion"))' -C metadata=ccb0e598b81f2f89 -C 
extra-filename=-e360b173386d7828 --out-dir 
/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps --extern 
once_cell=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libonce_cell-5d9acb04abc1e02f.rmeta
 --cap-lints warn -C linker=cc`
warning: use of deprecated module `std::usize`: all constants in this module 
replaced by associated constants on the type
  --> 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/thread_local-1.1.4/src/thread_id.rs:13:10
   |
13 | use std::usize;
   |          ^^^^^
   |
   = note: `#[warn(deprecated)]` on by default

warning: trait `UncheckedOptionExt` is never used
  --> 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/thread_local-1.1.4/src/unreachable.rs:11:11
   |
11 | pub trait UncheckedOptionExt<T> {
   |           ^^^^^^^^^^^^^^^^^^
   |
   = note: `#[warn(dead_code)]` (part of `#[warn(unused)]`) on by default

warning: method `unchecked_unwrap_err` is never used
  --> 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/thread_local-1.1.4/src/unreachable.rs:25:15
   |
20 | pub trait UncheckedResultExt<T, E> {
   |           ------------------ method in this trait
...
25 |     unsafe fn unchecked_unwrap_err(self) -> E;
   |               ^^^^^^^^^^^^^^^^^^^^

warning: unused return value of `Box::<T>::from_raw` that must be used
   --> 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/thread_local-1.1.4/src/lib.rs:158:22
    |
158 |             unsafe { 
Box::from_raw(std::slice::from_raw_parts_mut(bucket_ptr, this_bucket_size)) };
    |                      
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
    |
    = note: call `drop(Box::from_raw(ptr))` if you intend to drop the `Box`
    = note: `#[warn(unused_must_use)]` (part of `#[warn(unused)]`) on by default
help: use `let _ = ...` to ignore the resulting value
    |
158 |             unsafe { let _ = 
Box::from_raw(std::slice::from_raw_parts_mut(bucket_ptr, this_bucket_size)); };
    |                      +++++++                                              
                              +

warning: hiding a lifetime that's elided elsewhere is confusing
   --> 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/thread_local-1.1.4/src/lib.rs:296:21
    |
296 |     pub fn iter_mut(&mut self) -> IterMut<T> {
    |                     ^^^^^^^^^     ^^^^^^^^^^ the same lifetime is hidden 
here
    |                     |
    |                     the lifetime is elided here
    |
    = help: the same lifetime is referred to in inconsistent ways, making the 
signature confusing
    = note: `#[warn(mismatched_lifetime_syntaxes)]` on by default
help: use `'_` for type paths
    |
296 |     pub fn iter_mut(&mut self) -> IterMut<'_, T> {
    |                                           +++

warning: hiding a lifetime that's elided elsewhere is confusing
  --> 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/thread_local-1.1.4/src/cached.rs:65:21
   |
65 |     pub fn iter_mut(&mut self) -> CachedIterMut<T> {
   |                     ^^^^^^^^^     ^^^^^^^^^^^^^^^^ the same lifetime is 
hidden here
   |                     |
   |                     the lifetime is elided here
   |
   = help: the same lifetime is referred to in inconsistent ways, making the 
signature confusing
help: use `'_` for type paths
   |
65 |     pub fn iter_mut(&mut self) -> CachedIterMut<'_, T> {
   |                                                 +++

warning: `thread_local` (lib) generated 6 warnings
   Compiling httpdate v1.0.2
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=httpdate 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/httpdate-1.0.2
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/httpdate-1.0.2/Cargo.toml
 CARGO_PKG_AUTHORS='Pyfisch <[email protected]>' CARGO_PKG_DESCRIPTION='HTTP 
date parsing and formatting' CARGO_PKG_HOMEPAGE='' 
CARGO_PKG_LICENSE=MIT/Apache-2.0 CARGO_PKG_LICENSE_FILE='' 
CARGO_PKG_NAME=httpdate CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/pyfisch/httpdate' 
CARGO_PKG_RUST_VERSION='' CARGO_PKG_VERSION=1.0.2 CARGO_PKG_VERSION_MAJOR=1 
CARGO_PKG_VERSION_MINOR=0 CARGO_PKG_VERSION_PATCH=2 CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps 
/usr/local/bin/rustc --crate-name httpdate --edition=2018 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/httpdate-1.0.2/src/lib.rs
 --error-format=json --json=diagnostic
-rendered-ansi,artifacts,future-incompat --crate-type lib 
--emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --check-cfg 'cfg(docsrs,test)' --check-cfg 
'cfg(feature, values())' -C metadata=cf0264a5d8796448 -C 
extra-filename=-29abce4b67700e1b --out-dir 
/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps --cap-lints 
warn -C linker=cc`
   Compiling nu-ansi-term v0.50.3
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=nu_ansi_term 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/nu-ansi-term-0.50.3
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/nu-ansi-term-0.50.3/Cargo.toml
 CARGO_PKG_AUTHORS='[email protected]:Ryan Scheel (Havvy) 
<[email protected]>:Josh Triplett <[email protected]>:The Nushell 
Project Developers' CARGO_PKG_DESCRIPTION='Library for ANSI terminal colors and 
styles (bold, underline)' CARGO_PKG_HOMEPAGE='' CARGO_PKG_LICENSE=MIT 
CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NAME=nu-ansi-term 
CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/nushell/nu-ansi-term' 
CARGO_PKG_RUST_VERSION=1.62.1 CARGO_PKG_VERSION=0.50.3 
CARGO_PKG_VERSION_MAJOR=0 CARGO_PKG_VERSION_MINOR=50 CARGO_PKG_VERSION_PATCH=3 
CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps 
/usr/local/bin/rustc --crate-name nu_ansi_t
erm --edition=2021 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/nu-ansi-term-0.50.3/src/lib.rs
 --error-format=json --json=diagnostic-rendered-ansi,artifacts,future-incompat 
--crate-type lib --emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --cfg 'feature="default"' --cfg 
'feature="std"' --check-cfg 'cfg(docsrs,test)' --check-cfg 'cfg(feature, 
values("default", "derive_serde_style", "gnu_legacy", "serde", "std"))' -C 
metadata=031de47247bf784a -C extra-filename=-ad61a5930e13850b --out-dir 
/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps --cap-lints 
warn -C linker=cc`
   Compiling tracing-subscriber v0.3.20
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=tracing_subscriber 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/tracing-subscriber-0.3.20
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/tracing-subscriber-0.3.20/Cargo.toml
 CARGO_PKG_AUTHORS='Eliza Weisman <[email protected]>:David Barsky 
<[email protected]>:Tokio Contributors <[email protected]>' 
CARGO_PKG_DESCRIPTION='Utilities for implementing and composing `tracing` 
subscribers.
' CARGO_PKG_HOMEPAGE='https://tokio.rs' CARGO_PKG_LICENSE=MIT 
CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NAME=tracing-subscriber 
CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/tokio-rs/tracing' 
CARGO_PKG_RUST_VERSION=1.65.0 CARGO_PKG_VERSION=0.3.20 
CARGO_PKG_VERSION_MAJOR=0 CARGO_PKG_VERSION_MINOR=3 CARGO_PKG_VERSION_PATCH=20 
CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps 
/usr/local/bin/rustc --crate-name tracing_subscriber --edition=2018 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/tracing-subscriber-0.3.20/src/lib.rs
 --error-format=json --json=diagnostic-rendered-ansi,artifacts,future-incompat 
--crate-type lib --emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --warn=unexpected_cfgs --check-cfg 
'cfg(flaky_tests)' --check-cfg 'cfg(tracing_unstable)' --check-cfg 
'cfg(unsound_local_offset)' --cfg 'feature="alloc"' --cfg 'feature="ansi"' 
--cfg 
'feature="env-filter"' --cfg 'feature="fmt"' --cfg 'feature="matchers"' --cfg 
'feature="nu-ansi-term"' --cfg 'feature="once_cell"' --cfg 'feature="registry"' 
--cfg 'feature="sharded-slab"' --cfg 'feature="std"' --cfg 
'feature="thread_local"' --cfg 'feature="tracing"' --cfg 
'feature="tracing-log"' --check-cfg 'cfg(docsrs,test)' --check-cfg 
'cfg(feature, values("alloc", "ansi", "chrono", "default", "env-filter", "fmt", 
"json", "local-time", "matchers", "nu-ansi-term", "once_cell", "parking_lot", 
"regex", "registry", "serde", "serde_json", "sharded-slab", "smallvec", "std", 
"thread_local", "time", "tracing", "tracing-log", "tracing-serde", "valuable", 
"valuable-serde", "valuable_crate"))' -C metadata=5047d82149d72026 -C 
extra-filename=-19f98357d28661aa --out-dir 
/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps --extern 
matchers=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps
/libmatchers-12903dc96595f18d.rmeta --extern 
nu_ansi_term=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libnu_ansi_term-ad61a5930e13850b.rmeta
 --extern 
once_cell=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libonce_cell-5d9acb04abc1e02f.rmeta
 --extern 
regex_automata=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libregex_automata-307e72850065b13a.rmeta
 --extern 
sharded_slab=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libsharded_slab-8d700056ed51235d.rmeta
 --extern 
thread_local=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libthread_local-e360b173386d7828.rmeta
 --extern 
tracing=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libtracing-a102f387f058f9f7.rmeta
 --extern 
tracing_core=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libtracing_core-78bd3a1088ebf972.rmeta
 --extern 
tracing_log=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libtracing_log-f4210e0ba5c1c675.rmeta
 --cap-lints warn -C linker=cc`
warning: lint `no_mangle_generic_items` has been removed: converted into hard 
error, generic items must always be mangled
   --> 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/tracing-subscriber-0.3.20/src/lib.rs:186:5
    |
186 |     no_mangle_generic_items,
    |     ^^^^^^^^^^^^^^^^^^^^^^^
    |
    = note: `#[warn(renamed_and_removed_lints)]` on by default

   Compiling hyper v1.9.0
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=hyper 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/hyper-1.9.0
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/hyper-1.9.0/Cargo.toml
 CARGO_PKG_AUTHORS='Sean McArthur <[email protected]>' 
CARGO_PKG_DESCRIPTION='A protective and efficient HTTP library for all.' 
CARGO_PKG_HOMEPAGE='https://hyper.rs' CARGO_PKG_LICENSE=MIT 
CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NAME=hyper CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/hyperium/hyper' 
CARGO_PKG_RUST_VERSION=1.63 CARGO_PKG_VERSION=1.9.0 CARGO_PKG_VERSION_MAJOR=1 
CARGO_PKG_VERSION_MINOR=9 CARGO_PKG_VERSION_PATCH=0 CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps 
/usr/local/bin/rustc --crate-name hyper --edition=2021 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/hyper-1.9.0/src/lib.rs
 --error-format=json --json
=diagnostic-rendered-ansi,artifacts,future-incompat --crate-type lib 
--emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --warn=unexpected_cfgs --check-cfg 
'cfg(hyper_unstable_tracing)' --check-cfg 'cfg(hyper_unstable_ffi)' --cfg 
'feature="client"' --cfg 'feature="default"' --cfg 'feature="full"' --cfg 
'feature="http1"' --cfg 'feature="http2"' --cfg 'feature="server"' --check-cfg 
'cfg(docsrs,test)' --check-cfg 'cfg(feature, values("capi", "client", 
"default", "ffi", "full", "http1", "http2", "nightly", "server", "tracing"))' 
-C metadata=0c6f5b839453d458 -C extra-filename=-cba601fcd9952bc9 --out-dir 
/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps --extern 
atomic_waker=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libatomic_waker-386e7ab801411d95.rmeta
 --extern bytes=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/
libbytes-cd25042d4ca1c72f.rmeta --extern 
futures_channel=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libfutures_channel-e837824d95e7daaa.rmeta
 --extern 
futures_core=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libfutures_core-8a20179505a566c1.rmeta
 --extern 
h2=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libh2-68479d666e41b174.rmeta
 --extern 
http=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libhttp-6a830c499d791bc0.rmeta
 --extern 
http_body=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libhttp_body-1a2d5a40eaa5eb11.rmeta
 --extern 
httparse=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libhttparse-eda0affd5a496ace.rmeta
 --extern 
httpdate=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libhttpdate-29abce4b67700e1b.rmeta
 --extern 
itoa=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libitoa-00f03ef01ee56994.rmeta
 --extern 
pin_project_lite=/wrkdirs/usr/ports/www/wasmtime/work/target/release/dep
s/libpin_project_lite-a74ad4e41ecc3404.rmeta --extern 
smallvec=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libsmallvec-bee3925cca7e2f06.rmeta
 --extern 
tokio=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libtokio-de22396ecb88af47.rmeta
 --extern 
want=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libwant-3d21d9ff7343a254.rmeta
 --cap-lints warn -C linker=cc`
warning: `tracing-subscriber` (lib) generated 1 warning
     Running `CARGO=/usr/local/bin/cargo 
CARGO_CFG_FEATURE=default,openvino,winml CARGO_CFG_PANIC=unwind 
CARGO_CFG_TARGET_ABI='' CARGO_CFG_TARGET_ARCH=x86 
CARGO_CFG_TARGET_ENDIAN=little CARGO_CFG_TARGET_ENV='' 
CARGO_CFG_TARGET_FAMILY=unix CARGO_CFG_TARGET_FEATURE=fxsr,sse,sse2 
CARGO_CFG_TARGET_HAS_ATOMIC=16,32,64,8,ptr 
CARGO_CFG_TARGET_HAS_ATOMIC_PRIMITIVE_ALIGNMENT=16,32,8,ptr 
CARGO_CFG_TARGET_OS=freebsd CARGO_CFG_TARGET_POINTER_WIDTH=32 
CARGO_CFG_TARGET_VENDOR=unknown CARGO_CFG_UNIX='' 
CARGO_ENCODED_RUSTFLAGS='-Clinker=cc' CARGO_FEATURE_DEFAULT=1 
CARGO_FEATURE_OPENVINO=1 CARGO_FEATURE_WINML=1 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/crates/wasi-nn
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/crates/wasi-nn/Cargo.toml
 CARGO_PKG_AUTHORS='The Wasmtime Project Developers' 
CARGO_PKG_DESCRIPTION='Wasmtime implementation of the wasi-nn API' 
CARGO_PKG_HOMEPAGE='' CARGO_PKG_LICENSE='Apache-2.0 WITH LLVM-exception' 
CARGO_PKG
_LICENSE_FILE='' CARGO_PKG_NAME=wasmtime-wasi-nn CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/bytecodealliance/wasmtime' 
CARGO_PKG_RUST_VERSION=1.97.0 CARGO_PKG_VERSION=50.0.1 
CARGO_PKG_VERSION_MAJOR=50 CARGO_PKG_VERSION_MINOR=0 CARGO_PKG_VERSION_PATCH=1 
CARGO_PKG_VERSION_PRE='' DEBUG=false HOST=i686-unknown-freebsd 
LD_LIBRARY_PATH='/wrkdirs/usr/ports/www/wasmtime/work/target/release:/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps:/usr/local/lib/rustlib/i686-unknown-freebsd/lib'
 NUM_JOBS=3 OPT_LEVEL=2 
OUT_DIR=/wrkdirs/usr/ports/www/wasmtime/work/target/release/build/wasmtime-wasi-nn-503c3519300ea35a/out
 PROFILE=release RUSTC=/usr/local/bin/rustc RUSTDOC=/usr/local/bin/rustdoc 
TARGET=i686-unknown-freebsd 
/wrkdirs/usr/ports/www/wasmtime/work/target/release/build/wasmtime-wasi-nn-14c7b654b7bfc07f/build-script-build`
[wasmtime-wasi-nn 50.0.1] 
cargo:rerun-if-changed=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/crates/wasi-nn/witx
[wasmtime-wasi-nn 50.0.1] 
cargo:rerun-if-changed=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/crates/wasi-nn/witx/wasi-nn.witx
   Compiling file-per-thread-logger v0.2.0
     Running `CARGO=/usr/local/bin/cargo 
CARGO_CRATE_NAME=file_per_thread_logger 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/file-per-thread-logger-0.2.0
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/file-per-thread-logger-0.2.0/Cargo.toml
 CARGO_PKG_AUTHORS='Benjamin Bouvier <[email protected]>' CARGO_PKG_DESCRIPTION='A 
logging implementation that writes logs in one file per thread' 
CARGO_PKG_HOMEPAGE='' CARGO_PKG_LICENSE='Apache-2.0 WITH LLVM-exception' 
CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NAME=file-per-thread-logger 
CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/bnjbvr/file-per-thread-logger' 
CARGO_PKG_RUST_VERSION='' CARGO_PKG_VERSION=0.2.0 CARGO_PKG_VERSION_MAJOR=0 
CARGO_PKG_VERSION_MINOR=2 CARGO_PKG_VERSION_PATCH=0 CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps 
/usr/local/bin/rustc --crate-name file_per_thread_logger --edit
ion=2021 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/file-per-thread-logger-0.2.0/src/lib.rs
 --error-format=json --json=diagnostic-rendered-ansi,artifacts,future-incompat 
--crate-type lib --emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --check-cfg 'cfg(docsrs,test)' --check-cfg 
'cfg(feature, values())' -C metadata=d81ffc728c9df2e6 -C 
extra-filename=-2d38c125bd00327f --out-dir 
/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps --extern 
env_logger=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libenv_logger-6421c91c98f920d9.rmeta
 --extern 
log=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/liblog-577b4e335898a030.rmeta
 --cap-lints warn -C linker=cc`
   Compiling http-body-util v0.1.3
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=http_body_util 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/http-body-util-0.1.3
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/http-body-util-0.1.3/Cargo.toml
 CARGO_PKG_AUTHORS='Carl Lerche <[email protected]>:Lucio Franco 
<[email protected]>:Sean McArthur <[email protected]>' 
CARGO_PKG_DESCRIPTION='Combinators and adapters for HTTP request or response 
bodies.
' CARGO_PKG_HOMEPAGE='' CARGO_PKG_LICENSE=MIT CARGO_PKG_LICENSE_FILE='' 
CARGO_PKG_NAME=http-body-util CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/hyperium/http-body' 
CARGO_PKG_RUST_VERSION=1.61 CARGO_PKG_VERSION=0.1.3 CARGO_PKG_VERSION_MAJOR=0 
CARGO_PKG_VERSION_MINOR=1 CARGO_PKG_VERSION_PATCH=3 CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps 
/usr/local/bin/rustc --crate-name http_body_util --edition=2018 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/http-body-util-0.1.3/src/lib.rs
 --error-format=json --json=diagnostic-rendered-ansi,artifacts,future-incompat 
--crate-type lib --emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --cfg 'feature="default"' --check-cfg 
'cfg(docsrs,test)' --check-cfg 'cfg(feature, values("channel", "default", 
"full"))' -C metadata=6d188868fad5149c -C extra-filename=-d38c10e4470c1b6d 
--out-dir /wrkdirs/usr/port
s/www/wasmtime/work/target/release/deps -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps --extern 
bytes=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libbytes-cd25042d4ca1c72f.rmeta
 --extern 
futures_core=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libfutures_core-8a20179505a566c1.rmeta
 --extern 
http=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libhttp-6a830c499d791bc0.rmeta
 --extern 
http_body=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libhttp_body-1a2d5a40eaa5eb11.rmeta
 --extern 
pin_project_lite=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libpin_project_lite-a74ad4e41ecc3404.rmeta
 --cap-lints warn -C linker=cc`
warning: trait `MustNotImplDrop` is never used
   --> 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/http-body-util-0.1.3/src/either.rs:141:15
    |
141 |         trait MustNotImplDrop {}
    |               ^^^^^^^^^^^^^^^
    |
    = note: `#[warn(dead_code)]` (part of `#[warn(unused)]`) on by default

warning: hiding a lifetime that's elided elsewhere is confusing
  --> 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/http-body-util-0.1.3/src/either.rs:27:37
   |
27 |     pub(crate) fn project(self: Pin<&mut Self>) -> EitherProj<L, R> {
   |                                     ^^^^^^^^^      ^^^^^^^^^^^^^^^^ the 
same lifetime is hidden here
   |                                     |
   |                                     the lifetime is elided here
   |
   = help: the same lifetime is referred to in inconsistent ways, making the 
signature confusing
   = note: `#[warn(mismatched_lifetime_syntaxes)]` on by default
help: use `'_` for type paths
   |
27 |     pub(crate) fn project(self: Pin<&mut Self>) -> EitherProj<'_, L, R> {
   |                                                               +++

warning: `http-body-util` (lib) generated 2 warnings
   Compiling json-from-wast v0.261.0
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=json_from_wast 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/json-from-wast-0.261.0
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/json-from-wast-0.261.0/Cargo.toml
 CARGO_PKG_AUTHORS='' CARGO_PKG_DESCRIPTION='Conversion from `*.wast` files to 
JSON.
' CARGO_PKG_HOMEPAGE='' CARGO_PKG_LICENSE='Apache-2.0 WITH LLVM-exception OR 
Apache-2.0 OR MIT' CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NAME=json-from-wast 
CARGO_PKG_README='' 
CARGO_PKG_REPOSITORY='https://github.com/bytecodealliance/wasm-tools/tree/main/crates/json-from-wast'
 CARGO_PKG_RUST_VERSION=1.88.0 CARGO_PKG_VERSION=0.261.0 
CARGO_PKG_VERSION_MAJOR=0 CARGO_PKG_VERSION_MINOR=261 CARGO_PKG_VERSION_PATCH=0 
CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps 
/usr/local/bin/rustc --crate-name json_from_wast --edition=2024 
/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/cargo-crates/json-from-wast-0.261.0/src/lib.rs
 --error-format=json --json=diagnostic-rendered-ansi,artifacts,future-incompat 
--crate-type lib --emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 '--allow=clippy::all' 
--warn=unused_macro_rules --warn=unused_lifetimes --warn=unused_import_braces 
--warn=unused_extern_c
rates --warn=unstable_features --warn=unsafe_op_in_unsafe_fn --deny=unsafe_code 
--warn=unsafe_attr_outside_unsafe '--warn=clippy::unnecessary_to_owned' 
'--warn=clippy::unnecessary_mut_passed' 
'--warn=clippy::unnecessary_fallible_conversions' 
'--warn=clippy::unnecessary_cast' '--warn=clippy::uninlined_format_args' 
--warn=unexpected_cfgs --warn=rust_2024_prelude_collisions 
--warn=rust_2024_incompatible_pat 
--warn=rust_2024_guarded_string_incompatible_syntax 
--warn=missing_unsafe_on_extern '--warn=clippy::map_clone' 
'--warn=clippy::manual_strip' --warn=keyword_idents_2024 
--warn=deprecated_safe_2024 '--warn=clippy::clone_on_copy' --check-cfg 
'cfg(fuzzing)' --check-cfg 'cfg(debug_check_try_op)' --check-cfg 
'cfg(docsrs,test)' --check-cfg 'cfg(feature, values())' -C 
metadata=6cb435cbe7452138 -C extra-filename=-067ecf5b24b5f925 --out-dir 
/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps -
-extern 
anyhow=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libanyhow-a5ffa9d4ff9cd44e.rmeta
 --extern 
serde=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libserde-335197c3b8f13231.rmeta
 --extern 
serde_derive=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libserde_derive-23e6516bba13eb7d.so
 --extern 
wast=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libwast-d81a0df8cb8cb2f6.rmeta
 --cap-lints warn -C linker=cc`
   Compiling wasmtime-cli v50.0.1 
(/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1)
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=build_script_build 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/Cargo.toml
 CARGO_PKG_AUTHORS='The Wasmtime Project Developers' 
CARGO_PKG_DESCRIPTION='Command-line interface for Wasmtime' 
CARGO_PKG_HOMEPAGE='' CARGO_PKG_LICENSE='Apache-2.0 WITH LLVM-exception' 
CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NAME=wasmtime-cli 
CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/bytecodealliance/wasmtime' 
CARGO_PKG_RUST_VERSION=1.97.0 CARGO_PKG_VERSION=50.0.1 
CARGO_PKG_VERSION_MAJOR=50 CARGO_PKG_VERSION_MINOR=0 CARGO_PKG_VERSION_PATCH=1 
CARGO_PKG_VERSION_PRE='' CARGO_PRIMARY_PACKAGE=1 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps 
/usr/local/bin/rustc --crate-name build_script_build --edition=2024 build.rs 
--error-format=json --json=diagnostic-rendered-ansi,artifacts,future-incompat 
--crate-typ
e bin --emit=dep-info,link -C embed-bitcode=no '--allow=clippy::all' 
'--warn=clippy::useless_conversion' --warn=unused_macro_rules 
--warn=unused_lifetimes --warn=unused_import_braces --warn=unused_extern_crates 
--warn=unstable_features '--warn=clippy::unnecessary_to_owned' 
'--warn=clippy::unnecessary_mut_passed' 
'--warn=clippy::unnecessary_fallible_conversions' 
'--warn=clippy::unnecessary_cast' '--warn=clippy::uninlined_format_args' 
--warn=unexpected_cfgs --warn=trivial_numeric_casts 
'--warn=clippy::redundant_field_names' 
'--warn=clippy::multiple_bound_locations' '--warn=clippy::map_clone' 
'--warn=clippy::manual_strip' '--warn=clippy::from_over_into' 
'--warn=clippy::extra_unused_type_parameters' '--warn=clippy::clone_on_copy' 
'--warn=clippy::allow_attributes_without_reason' --check-cfg 
'cfg(pulley_tail_calls)' --check-cfg 'cfg(pulley_assume_llvm_makes_tail_calls)' 
--check-cfg 'cfg(pulley_disable_interp_simd)' --check-cfg 'cfg(arc_try_new)' 
--check-cfg 'cfg(fuzzing)' --check-
cfg 'cfg(gc_zeal)' -C debug-assertions=off --cfg 'feature="addr2line"' --cfg 
'feature="backtrace"' --cfg 'feature="cache"' --cfg 'feature="compile"' --cfg 
'feature="compile-time-builtins"' --cfg 'feature="completion"' --cfg 
'feature="component-model"' --cfg 'feature="component-model-async"' --cfg 
'feature="config"' --cfg 'feature="coredump"' --cfg 'feature="cranelift"' --cfg 
'feature="debug"' --cfg 'feature="debug-builtins"' --cfg 'feature="default"' 
--cfg 'feature="demangle"' --cfg 'feature="explore"' --cfg 'feature="gc"' --cfg 
'feature="gc-copying"' --cfg 'feature="gc-drc"' --cfg 'feature="gc-null"' --cfg 
'feature="hot-blocks"' --cfg 'feature="logging"' --cfg 'feature="objdump"' 
--cfg 'feature="parallel-compilation"' --cfg 'feature="pooling-allocator"' 
--cfg 'feature="profiling"' --cfg 'feature="pulley"' --cfg 
'feature="pulley-interpreter"' --cfg 'feature="run"' --cfg 'feature="serve"' 
--cfg 'feature="stack-switching"' --cfg 'feature="threads"' --cfg 
'feature="wasi-config"
' --cfg 'feature="wasi-http"' --cfg 'feature="wasi-keyvalue"' --cfg 
'feature="wasi-nn"' --cfg 'feature="wasi-tls"' --cfg 'feature="wasmtime-wizer"' 
--cfg 'feature="wast"' --cfg 'feature="wat"' --cfg 'feature="winch"' --cfg 
'feature="wizer"' --check-cfg 'cfg(docsrs,test)' --check-cfg 'cfg(feature, 
values("addr2line", "all-arch", "backtrace", "cache", "compile", 
"compile-time-builtins", "completion", "component-model", 
"component-model-async", "config", "coredump", "cranelift", "debug", 
"debug-builtins", "default", "demangle", "disable-logging", "explore", "gc", 
"gc-copying", "gc-drc", "gc-null", "gdbstub", "hot-blocks", "logging", 
"memory-protection-keys", "objdump", "parallel-compilation", 
"pooling-allocator", "profile-pulley", "profiling", "pulley", 
"pulley-interpreter", "rr", "run", "serve", "stack-switching", "threads", 
"trace-log", "wasi-config", "wasi-http", "wasi-keyvalue", "wasi-nn", 
"wasi-tls", "wasmtime-wizer", "wast", "wat", "winch", "wizer", "wmemcheck"))' 
-C meta
data=d4ea838de0b6328e -C extra-filename=-bd8264bc9370f592 --out-dir 
/wrkdirs/usr/ports/www/wasmtime/work/target/release/build/wasmtime-cli-bd8264bc9370f592
 -C strip=debuginfo -L 
dependency=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps -C 
linker=cc`
     Running `CARGO=/usr/local/bin/cargo 
CARGO_CFG_FEATURE=addr2line,backtrace,cache,compile,compile-time-builtins,completion,component-model,component-model-async,config,coredump,cranelift,debug,debug-builtins,default,demangle,explore,gc,gc-copying,gc-drc,gc-null,hot-blocks,logging,objdump,parallel-compilation,pooling-allocator,profiling,pulley,pulley-interpreter,run,serve,stack-switching,threads,wasi-config,wasi-http,wasi-keyvalue,wasi-nn,wasi-tls,wasmtime-wizer,wast,wat,winch,wizer
 CARGO_CFG_PANIC=unwind CARGO_CFG_TARGET_ABI='' CARGO_CFG_TARGET_ARCH=x86 
CARGO_CFG_TARGET_ENDIAN=little CARGO_CFG_TARGET_ENV='' 
CARGO_CFG_TARGET_FAMILY=unix CARGO_CFG_TARGET_FEATURE=fxsr,sse,sse2 
CARGO_CFG_TARGET_HAS_ATOMIC=16,32,64,8,ptr 
CARGO_CFG_TARGET_HAS_ATOMIC_PRIMITIVE_ALIGNMENT=16,32,8,ptr 
CARGO_CFG_TARGET_OS=freebsd CARGO_CFG_TARGET_POINTER_WIDTH=32 
CARGO_CFG_TARGET_VENDOR=unknown CARGO_CFG_UNIX='' 
CARGO_ENCODED_RUSTFLAGS='-Clinker=cc' CARGO_FEATURE_ADDR2LINE=1 
CARGO_FEATURE_BACKTRACE=
1 CARGO_FEATURE_CACHE=1 CARGO_FEATURE_COMPILE=1 
CARGO_FEATURE_COMPILE_TIME_BUILTINS=1 CARGO_FEATURE_COMPLETION=1 
CARGO_FEATURE_COMPONENT_MODEL=1 CARGO_FEATURE_COMPONENT_MODEL_ASYNC=1 
CARGO_FEATURE_CONFIG=1 CARGO_FEATURE_COREDUMP=1 CARGO_FEATURE_CRANELIFT=1 
CARGO_FEATURE_DEBUG=1 CARGO_FEATURE_DEBUG_BUILTINS=1 CARGO_FEATURE_DEFAULT=1 
CARGO_FEATURE_DEMANGLE=1 CARGO_FEATURE_EXPLORE=1 CARGO_FEATURE_GC=1 
CARGO_FEATURE_GC_COPYING=1 CARGO_FEATURE_GC_DRC=1 CARGO_FEATURE_GC_NULL=1 
CARGO_FEATURE_HOT_BLOCKS=1 CARGO_FEATURE_LOGGING=1 CARGO_FEATURE_OBJDUMP=1 
CARGO_FEATURE_PARALLEL_COMPILATION=1 CARGO_FEATURE_POOLING_ALLOCATOR=1 
CARGO_FEATURE_PROFILING=1 CARGO_FEATURE_PULLEY=1 
CARGO_FEATURE_PULLEY_INTERPRETER=1 CARGO_FEATURE_RUN=1 CARGO_FEATURE_SERVE=1 
CARGO_FEATURE_STACK_SWITCHING=1 CARGO_FEATURE_THREADS=1 
CARGO_FEATURE_WASI_CONFIG=1 CARGO_FEATURE_WASI_HTTP=1 
CARGO_FEATURE_WASI_KEYVALUE=1 CARGO_FEATURE_WASI_NN=1 CARGO_FEATURE_WASI_TLS=1 
CARGO_FEATURE_WASMTIME_WIZER=1 CARGO_FEATURE_WAST=1 
CARGO_FEATURE_WAT=1 CARGO_FEATURE_WINCH=1 CARGO_FEATURE_WIZER=1 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/Cargo.toml
 CARGO_PKG_AUTHORS='The Wasmtime Project Developers' 
CARGO_PKG_DESCRIPTION='Command-line interface for Wasmtime' 
CARGO_PKG_HOMEPAGE='' CARGO_PKG_LICENSE='Apache-2.0 WITH LLVM-exception' 
CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NAME=wasmtime-cli 
CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/bytecodealliance/wasmtime' 
CARGO_PKG_RUST_VERSION=1.97.0 CARGO_PKG_VERSION=50.0.1 
CARGO_PKG_VERSION_MAJOR=50 CARGO_PKG_VERSION_MINOR=0 CARGO_PKG_VERSION_PATCH=1 
CARGO_PKG_VERSION_PRE='' DEBUG=false HOST=i686-unknown-freebsd 
LD_LIBRARY_PATH='/wrkdirs/usr/ports/www/wasmtime/work/target/release:/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps:/usr/local/lib/rustlib/i686-unknown-freebsd/lib'
 NUM_JOBS=3 OPT_LEVEL=2 OUT_DIR=/wrkdirs/usr/ports/www/wasmtime/
work/target/release/build/wasmtime-cli-2fb999106efed195/out PROFILE=release 
RUSTC=/usr/local/bin/rustc RUSTDOC=/usr/local/bin/rustdoc 
TARGET=i686-unknown-freebsd 
/wrkdirs/usr/ports/www/wasmtime/work/target/release/build/wasmtime-cli-bd8264bc9370f592/build-script-build`
[wasmtime-cli 50.0.1] cargo:rerun-if-changed=build.rs
[wasmtime-cli 50.0.1] cargo:rustc-check-cfg=cfg(asan)
   Compiling wasmtime-wast v50.0.1 
(/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/crates/wast)
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=wasmtime_wast 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/crates/wast
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/crates/wast/Cargo.toml
 CARGO_PKG_AUTHORS='The Wasmtime Project Developers' 
CARGO_PKG_DESCRIPTION='wast testing support for wasmtime' CARGO_PKG_HOMEPAGE='' 
CARGO_PKG_LICENSE='Apache-2.0 WITH LLVM-exception' CARGO_PKG_LICENSE_FILE='' 
CARGO_PKG_NAME=wasmtime-wast CARGO_PKG_README='' 
CARGO_PKG_REPOSITORY='https://github.com/bytecodealliance/wasmtime' 
CARGO_PKG_RUST_VERSION=1.97.0 CARGO_PKG_VERSION=50.0.1 
CARGO_PKG_VERSION_MAJOR=50 CARGO_PKG_VERSION_MINOR=0 CARGO_PKG_VERSION_PATCH=1 
CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps 
/usr/local/bin/rustc --crate-name wasmtime_wast --edition=2024 
crates/wast/src/lib.rs --error-format=json 
--json=diagnostic-rendered-ansi,artifacts,future-incompat --crate-type li
b --emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 '--allow=clippy::all' 
'--warn=clippy::useless_conversion' --warn=unused_macro_rules 
--warn=unused_lifetimes --warn=unused_import_braces --warn=unused_extern_crates 
--warn=unstable_features '--warn=clippy::unnecessary_to_owned' 
'--warn=clippy::unnecessary_mut_passed' 
'--warn=clippy::unnecessary_fallible_conversions' 
'--warn=clippy::unnecessary_cast' '--warn=clippy::uninlined_format_args' 
--warn=unexpected_cfgs --warn=trivial_numeric_casts 
'--warn=clippy::redundant_field_names' 
'--warn=clippy::multiple_bound_locations' '--warn=clippy::map_clone' 
'--warn=clippy::manual_strip' '--warn=clippy::from_over_into' 
'--warn=clippy::extra_unused_type_parameters' '--warn=clippy::clone_on_copy' 
'--warn=clippy::allow_attributes_without_reason' --check-cfg 
'cfg(pulley_tail_calls)' --check-cfg 'cfg(pulley_assume_llvm_makes_tail_calls)' 
--check-cfg 'cfg(pulley_disable_interp_simd)' --check-cfg
 'cfg(arc_try_new)' --check-cfg 'cfg(fuzzing)' --check-cfg 'cfg(gc_zeal)' --cfg 
'feature="component-model"' --check-cfg 'cfg(docsrs,test)' --check-cfg 
'cfg(feature, values("component-model", "component-model-async"))' -C 
metadata=a5226012d130016e -C extra-filename=-aff95a4c71177456 --out-dir 
/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps --extern 
json_from_wast=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libjson_from_wast-067ecf5b24b5f925.rmeta
 --extern 
log=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/liblog-577b4e335898a030.rmeta
 --extern 
object=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libobject-b1503eb568142b14.rmeta
 --extern 
serde_json=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libserde_json-484e44be98679ad4.rmeta
 --extern 
tokio=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libtokio-de22396ecb88af47.rmeta
 --ext
ern 
wasmparser=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libwasmparser-93e92257d8b83ec5.rmeta
 --extern 
wasmtime=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libwasmtime-2fb427f86f2d1c49.rmeta
 --extern 
wast=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libwast-d81a0df8cb8cb2f6.rmeta
 -C linker=cc -L 
native=/wrkdirs/usr/ports/www/wasmtime/work/target/release/build/capstone-sys-280ce589d77620d9/out
 -L 
native=/wrkdirs/usr/ports/www/wasmtime/work/target/release/build/wasmtime-internal-jit-debug-bb9e09142f23c4e4/out
 -L native=/usr/local/lib`
   Compiling wasmtime-cli-flags v50.0.1 
(/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/crates/cli-flags)
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=wasmtime_cli_flags 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/crates/cli-flags
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/crates/cli-flags/Cargo.toml
 CARGO_PKG_AUTHORS='The Wasmtime Project Developers' 
CARGO_PKG_DESCRIPTION='Exposes common CLI flags used for running Wasmtime' 
CARGO_PKG_HOMEPAGE='' CARGO_PKG_LICENSE='Apache-2.0 WITH LLVM-exception' 
CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NAME=wasmtime-cli-flags CARGO_PKG_README='' 
CARGO_PKG_REPOSITORY='https://github.com/bytecodealliance/wasmtime' 
CARGO_PKG_RUST_VERSION=1.97.0 CARGO_PKG_VERSION=50.0.1 
CARGO_PKG_VERSION_MAJOR=50 CARGO_PKG_VERSION_MINOR=0 CARGO_PKG_VERSION_PATCH=1 
CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps 
/usr/local/bin/rustc --crate-name wasmtime_cli_flags --edition=2024 
crates/cli-flags/src/lib.rs --error-format=json --json=diagnostic-rendered
-ansi,artifacts,future-incompat --crate-type lib --emit=dep-info,metadata,link 
-C opt-level=2 -C panic=abort -C linker-plugin-lto -C codegen-units=1 
'--allow=clippy::all' '--warn=clippy::useless_conversion' 
--warn=unused_macro_rules --warn=unused_lifetimes --warn=unused_import_braces 
--warn=unused_extern_crates --warn=unstable_features 
'--warn=clippy::unnecessary_to_owned' '--warn=clippy::unnecessary_mut_passed' 
'--warn=clippy::unnecessary_fallible_conversions' 
'--warn=clippy::unnecessary_cast' '--warn=clippy::uninlined_format_args' 
--warn=unexpected_cfgs --warn=trivial_numeric_casts 
'--warn=clippy::redundant_field_names' 
'--warn=clippy::multiple_bound_locations' '--warn=clippy::map_clone' 
'--warn=clippy::manual_strip' '--warn=clippy::from_over_into' 
'--warn=clippy::extra_unused_type_parameters' '--warn=clippy::clone_on_copy' 
'--warn=clippy::allow_attributes_without_reason' --check-cfg 
'cfg(pulley_tail_calls)' --check-cfg 'cfg(pulley_assume_llvm_makes_tail_calls)' 
--check-cf
g 'cfg(pulley_disable_interp_simd)' --check-cfg 'cfg(arc_try_new)' --check-cfg 
'cfg(fuzzing)' --check-cfg 'cfg(gc_zeal)' --cfg 'feature="async"' --cfg 
'feature="cache"' --cfg 'feature="clap"' --cfg 'feature="component-model"' 
--cfg 'feature="component-model-async"' --cfg 'feature="coredump"' --cfg 
'feature="cranelift"' --cfg 'feature="debug"' --cfg 'feature="gc"' --cfg 
'feature="gc-copying"' --cfg 'feature="gc-drc"' --cfg 'feature="gc-null"' --cfg 
'feature="logging"' --cfg 'feature="parallel-compilation"' --cfg 
'feature="pooling-allocator"' --cfg 'feature="pulley"' --cfg 'feature="serde"' 
--cfg 'feature="stack-switching"' --cfg 'feature="threads"' --cfg 
'feature="toml"' --check-cfg 'cfg(docsrs,test)' --check-cfg 'cfg(feature, 
values("async", "cache", "clap", "component-model", "component-model-async", 
"coredump", "cranelift", "debug", "gc", "gc-copying", "gc-drc", "gc-null", 
"logging", "memory-protection-keys", "parallel-compilation", 
"pooling-allocator", "pulley", "rr", "se
rde", "stack-switching", "threads", "toml"))' -C metadata=af72d83b0c9862d2 -C 
extra-filename=-955150e4aaff0b8a --out-dir 
/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps --extern 
clap=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libclap-7f26c2cded095b55.rmeta
 --extern 
file_per_thread_logger=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libfile_per_thread_logger-2d38c125bd00327f.rmeta
 --extern 
rayon=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/librayon-2665d83603879cbc.rmeta
 --extern 
serde=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libserde-335197c3b8f13231.rmeta
 --extern 
serde_derive=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libserde_derive-23e6516bba13eb7d.so
 --extern 
toml=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libtoml-748007e8268f7409.rmeta
 --extern tracing_subscriber=/wrkdirs/usr/ports/www/wasmtim
e/work/target/release/deps/libtracing_subscriber-19f98357d28661aa.rmeta 
--extern 
wasmtime=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libwasmtime-2fb427f86f2d1c49.rmeta
 -C linker=cc -L 
native=/wrkdirs/usr/ports/www/wasmtime/work/target/release/build/capstone-sys-280ce589d77620d9/out
 -L 
native=/wrkdirs/usr/ports/www/wasmtime/work/target/release/build/wasmtime-internal-jit-debug-bb9e09142f23c4e4/out
 -L native=/usr/local/lib`
For more information about this error, try `rustc --explain E0308`.
error: could not compile `wasmtime-wasi` (lib) due to 3 previous errors

Caused by:
  process didn't exit successfully: `CARGO=/usr/local/bin/cargo 
CARGO_CRATE_NAME=wasmtime_wasi 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/crates/wasi
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/www/wasmtime/work/wasmtime-50.0.1/crates/wasi/Cargo.toml
 CARGO_PKG_AUTHORS='The Wasmtime Project Developers' 
CARGO_PKG_DESCRIPTION='WASI implementation in Rust' CARGO_PKG_HOMEPAGE='' 
CARGO_PKG_LICENSE='Apache-2.0 WITH LLVM-exception' CARGO_PKG_LICENSE_FILE='' 
CARGO_PKG_NAME=wasmtime-wasi CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/bytecodealliance/wasmtime' 
CARGO_PKG_RUST_VERSION=1.97.0 CARGO_PKG_VERSION=50.0.1 
CARGO_PKG_VERSION_MAJOR=50 CARGO_PKG_VERSION_MINOR=0 CARGO_PKG_VERSION_PATCH=1 
CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps 
/usr/local/bin/rustc --crate-name wasmtime_wasi --edition=2024 
crates/wasi/src/lib.rs --error-format=json 
--json=diagnostic-rendered-ansi,artifacts,future-
incompat --crate-type lib --emit=dep-info,metadata,link -C opt-level=2 -C 
panic=abort -C linker-plugin-lto -C codegen-units=1 '--allow=clippy::all' 
'--warn=clippy::useless_conversion' --warn=unused_macro_rules 
--warn=unused_lifetimes --warn=unused_import_braces --warn=unused_extern_crates 
--warn=unstable_features '--warn=clippy::unnecessary_to_owned' 
'--warn=clippy::unnecessary_mut_passed' 
'--warn=clippy::unnecessary_fallible_conversions' 
'--warn=clippy::unnecessary_cast' '--warn=clippy::uninlined_format_args' 
--warn=unexpected_cfgs --warn=trivial_numeric_casts 
'--warn=clippy::redundant_field_names' 
'--warn=clippy::multiple_bound_locations' '--warn=clippy::map_clone' 
'--warn=clippy::manual_strip' '--warn=clippy::from_over_into' 
'--warn=clippy::extra_unused_type_parameters' '--warn=clippy::clone_on_copy' 
'--warn=clippy::allow_attributes_without_reason' --check-cfg 
'cfg(pulley_tail_calls)' --check-cfg 'cfg(pulley_assume_llvm_makes_tail_calls)' 
--check-cfg 'cfg(pulley_disable_i
nterp_simd)' --check-cfg 'cfg(arc_try_new)' --check-cfg 'cfg(fuzzing)' 
--check-cfg 'cfg(gc_zeal)' --cfg 'feature="default"' --cfg 'feature="p1"' --cfg 
'feature="p2"' --cfg 'feature="p3"' --check-cfg 'cfg(docsrs,test)' --check-cfg 
'cfg(feature, values("default", "p0", "p1", "p2", "p3"))' -C 
metadata=1f11f83df4ec9912 -C extra-filename=-4d604b89f7eeb145 --out-dir 
/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps --extern 
async_trait=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libasync_trait-7f4ccf529f5a06fb.so
 --extern 
bitflags=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libbitflags-47340f081a54da07.rmeta
 --extern 
bytes=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libbytes-cd25042d4ca1c72f.rmeta
 --extern 
futures=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libfutures-e0e6ca8057aeea7f.rmeta
 --extern rand=/wrkdirs/usr/ports/www/wasmtime/
work/target/release/deps/librand-bde5a82b581880cc.rmeta --extern 
rustix=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/librustix-4a2f9b25715bccc9.rmeta
 --extern 
rustix_linux_procfs=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/librustix_linux_procfs-0a6030a1a65a9658.rmeta
 --extern 
thiserror=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libthiserror-b51b373a5c713e23.rmeta
 --extern 
tokio=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libtokio-de22396ecb88af47.rmeta
 --extern 
tracing=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libtracing-a102f387f058f9f7.rmeta
 --extern 
url=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/liburl-4ee93cb7ad4423b8.rmeta
 --extern 
wasmtime=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libwasmtime-2fb427f86f2d1c49.rmeta
 --extern 
wasmtime_wasi_io=/wrkdirs/usr/ports/www/wasmtime/work/target/release/deps/libwasmtime_wasi_io-acef372435d0be0b.rmeta
 --extern wiggle=/wrkdirs/usr/ports/
www/wasmtime/work/target/release/deps/libwiggle-7741f0d3321496bf.rmeta -C 
linker=cc -L 
native=/wrkdirs/usr/ports/www/wasmtime/work/target/release/build/capstone-sys-280ce589d77620d9/out
 -L 
native=/wrkdirs/usr/ports/www/wasmtime/work/target/release/build/wasmtime-internal-jit-debug-bb9e09142f23c4e4/out
 -L native=/usr/local/lib` (exit status: 1)
warning: build failed, waiting for other jobs to finish...
*** Error code 101

Stop.
make: stopped making "build" in /usr/ports/www/wasmtime

Reply via email to